.. miniwdl documentation master file, created by
   sphinx-quickstart on Tue Sep  4 15:20:37 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

WDL Python package
==================

.. contents::

.. automodule:: WDL
   :members:

Tree
----
.. automodule:: WDL.Tree
   :members:
   :show-inheritance:

Expr
----

.. automodule:: WDL.Expr
   :members:
   :show-inheritance:

Env
---
.. automodule:: WDL.Env
   :members:
   :show-inheritance:

Type
----

.. automodule:: WDL.Type
   :members:
   :show-inheritance:

Value
-----
.. automodule:: WDL.Value
   :members:
   :show-inheritance:

Error
-----
.. automodule:: WDL.Error
   :members:
   :show-inheritance:

Lint
----
.. automodule:: WDL.Lint
